#!/usr/bin/env python
# (C) 2017 OpenEye Scientific Software Inc. All rights reserved.
#
# TERMS FOR USE OF SAMPLE CODE The software below ("Sample Code") is
# provided to current licensees or subscribers of OpenEye products or
# SaaS offerings (each a "Customer").
# Customer is hereby permitted to use, copy, and modify the Sample Code,
# subject to these terms. OpenEye claims no rights to Customer's
# modifications. Modification of Sample Code is at Customer's sole and
# exclusive risk. Sample Code may require Customer to have a then
# current license or subscription to the applicable OpenEye offering.
# THE SAMPLE CODE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
# EXPRESS OR IMPLIED.  OPENEYE DISCLAIMS ALL WARRANTIES, INCLUDING, BUT
# NOT LIMITED TO, WARRANTIES OF MERCHANTABILITY, FITNESS FOR A
# PARTICULAR PURPOSE AND NONINFRINGEMENT. In no event shall OpenEye be
# liable for any damages or liability in connection with the Sample Code
# or its use.

# @ <SNIPPET>
import sys
from openeye import oechem


def SplitMolComplexIter(oms, mol):
    # limiting lig, prot and wat to just near the first binding site
    # (a very common pattern)

    # @ <SNIPPET-SPLIT-MOL-COMPLEX-ITER-SIMPLE>
    # for input molecule mol ...
    for frag in oechem.OEGetMolComplexComponents(mol):
        # ...
        # @ </SNIPPET-SPLIT-MOL-COMPLEX-ITER-SIMPLE>
        oechem.OEWriteMolecule(oms, frag)

    # other api points illustrated below

    # @ <SNIPPET-SPLIT-MOL-COMPLEX-SPLIT-COVALENT>
    opt = oechem.OESplitMolComplexOptions()
    opt.SetSplitCovalent()
    # @ </SNIPPET-SPLIT-MOL-COMPLEX-SPLIT-COVALENT>

    # @ <SNIPPET-SPLIT-MOL-FILTER-SURFACE-WATERS>
    site = 1
    surfaceWaters = True
    opt.ResetFilters(site, surfaceWaters)
    opt.SetMaxSurfaceWaterDist(8.0)
    # @ </SNIPPET-SPLIT-MOL-FILTER-SURFACE-WATERS>


def SplitMolComplexIterLigName(oms, mol, ligName):
    # the ligand has been identified by name

    # @ <SNIPPET-SPLIT-MOL-COMPLEX-ITER-LIGNAME>
    # for input molecule mol and string ligName ...
    opt = oechem.OESplitMolComplexOptions(ligName)

    for frag in oechem.OEGetMolComplexComponents(mol, opt):
        # ...
        # @ </SNIPPET-SPLIT-MOL-COMPLEX-ITER-LIGNAME>
        oechem.OEWriteMolecule(oms, frag)


def SplitMolComplexIterAllSites(oms, mol):
    # @ <SNIPPET-SPLIT-MOL-COMPLEX-ITER-ALL-SITES>
    opt = oechem.OESplitMolComplexOptions()
    allSites = 0
    opt.ResetFilters(allSites)

    for frag in oechem.OEGetMolComplexComponents(mol, opt):
        # ...
        # @ </SNIPPET-SPLIT-MOL-COMPLEX-ITER-ALL-SITES>
        oechem.OEWriteMolecule(oms, frag)


def SplitMolComplexIterAllSitesLigName(oms, mol, ligName):
    # @ <SNIPPET-SPLIT-MOL-COMPLEX-ITER-LIGNAME-AND-ALL-SITES>
    opt = oechem.OESplitMolComplexOptions(ligName)
    allSites = 0
    opt.ResetFilters(allSites)

    for frag in oechem.OEGetMolComplexComponents(mol, opt):
        # ...
        # @ </SNIPPET-SPLIT-MOL-COMPLEX-ITER-LIGNAME-AND-ALL-SITES>
        oechem.OEWriteMolecule(oms, frag)


def SplitMolComplexIterFilter(oms, mol):
    # @ <SNIPPET-SPLIT-MOL-COMPLEX-ADD-COFACTOR>
    db = oechem.OEResidueCategoryData()
    db.AddToDB(oechem.OEResidueDatabaseCategory_Cofactor, "MTQ")

    cat = oechem.OEMolComplexCategorizer()
    cat.SetResidueCategoryData(db)

    opt = oechem.OESplitMolComplexOptions()
    opt.SetCategorizer(cat)
    # @ </SNIPPET-SPLIT-MOL-COMPLEX-ADD-COFACTOR>

    # @ <SNIPPET-SPLIT-MOL-COMPLEX-ITER-FILTER>
    # for input molecule mol and options opt ...
    for l in oechem.OEGetMolComplexComponents(mol, opt, opt.GetLigandFilter()):
        # ...
        # @ </SNIPPET-SPLIT-MOL-COMPLEX-ITER-FILTER>
        oechem.OEWriteMolecule(oms, l)

    # @ <SNIPPET-SPLIT-MOL-COMPLEX-EXAMPLE-FILTER>
    ofilter = opt.GetOtherFilter()
    # @ </SNIPPET-SPLIT-MOL-COMPLEX-EXAMPLE-FILTER>
    rs = oechem.OERoles()
    ofilter(rs)


def main(argv=[__name__]):

    itf = oechem.OEInterface(InterfaceData)

    if not oechem.OEParseCommandLine(itf, argv):
        oechem.OEThrow.Fatal("Unable to interpret command line!")

    iname = itf.GetString("-i")
    oname = itf.GetString("-o")

    ims = oechem.oemolistream()
    if not ims.open(iname):
        oechem.OEThrow.Fatal("Cannot open input file!")

    oms = oechem.oemolostream()
    if not oms.open(oname):
        oechem.OEThrow.Fatal("Cannot open output file!")

    inmol = oechem.OEGraphMol()
    if not oechem.OEReadMolecule(ims, inmol):
        oechem.OEThrow.Fatal("Cannot read input file!")

    allSites = itf.GetBool("-a")
    filterLigand = itf.GetBool("-f")

    # break out each scheme to better illustrate them
    if filterLigand:
        SplitMolComplexIterFilter(oms, inmol)
    elif itf.HasString("-l"):
        ligName = itf.GetString("-l")
        if allSites:
            SplitMolComplexIterAllSitesLigName(oms, inmol, ligName)
        else:
            SplitMolComplexIterLigName(oms, inmol, ligName)
    else:
        if allSites:
            SplitMolComplexIterAllSites(oms, inmol)
        else:
            SplitMolComplexIter(oms, inmol)

    oms.close()


#############################################################################
# INTERFACE
#############################################################################

InterfaceData = '''
!BRIEF SplitMolComplexIterDoc.py <molfile> [<outfile> [ligname]]

!PARAMETER -i
  !TYPE string
  !BRIEF Input molecule (usually a pdb file)
  !REQUIRED true
  !KEYLESS 1
!END
!PARAMETER -o
  !TYPE string
  !DEFAULT splitmolcomplexiter.oeb.gz
  !BRIEF Output molecule (usually an oeb)
  !REQUIRED false
  !KEYLESS 2
!END
!PARAMETER -l
  !TYPE string
  !BRIEF Explicit ligand name
  !REQUIRED false
  !KEYLESS 3
!END
!PARAMETER -a
  !TYPE bool
  !DEFAULT false
  !BRIEF If true, show all binding sites, not just the first
  !REQUIRED false
!END
!PARAMETER -f
  !TYPE bool
  !DEFAULT false
  !BRIEF If true, use just the ligand filter
  !REQUIRED false
!END
'''


if __name__ == "__main__":
    sys.exit(main(sys.argv))

# @ </SNIPPET>



# CONFIDENTIAL. (C) 2017 OpenEye Scientific Software Inc.
# All rights reserved.
# 
# ALL SOFTWARE BELOW IS PROPRIETARY AND CONFIDENTIAL TO OPENEYE
# SCIENTIFIC SOFTWARE INC., AND IS SUBJECT TO THE FULL PROTECTION OF
# COPYRIGHT AND TRADESECRET LAW.
# Copying or modifying this software is strictly prohibited and illegal.
# Using this software without a valid license from OpenEye is strictly
# prohibited and illegal.  De-obfuscating, de-minimizing, or any other
# attempt to reverse engineer or discover the workings of this software,
# is strictly prohibited. Even if software is exposed or visible, it is
# still proprietary and confidential and the above prohibitions apply.
# This software is NOT "Sample Code". For purposes of customization or
# interoperation with other software you must use Sample Code
# specifically labeled as such.
# Please contact OpenEye at eyesopen.com/legal if you have any questions
# about this warning.


# This file was automatically generated by SWIG (http://www.swig.org).
# Version 3.0.12
#
# Do not make changes to this file unless you know what you are doing--modify
# the SWIG interface file instead.

from sys import version_info as _swig_python_version_info

def swig_import_helper():
    from os.path import dirname
    import importlib.util

    spec = importlib.machinery.PathFinder().find_spec("_oechem", [dirname(__file__)])

    if spec is None:
        # OpenEye Import Statements
        spec = importlib.machinery.PathFinder().find_spec("libs",[dirname(__file__)])
    libs = importlib.util.module_from_spec(spec)

    import sys
    sys.modules[spec.name] = libs
    spec.loader.exec_module(libs)

    assert not sys.platform.startswith('win')

    _oeszmap = libs.OEGetModule('_oeszmap1605')
    return _oeszmap

_oeszmap = swig_import_helper()
del swig_import_helper
del _swig_python_version_info

try:
    _swig_property = property
except NameError:
    pass  # Python < 2.2 doesn't have 'property'.

try:
    import builtins as __builtin__
except ImportError:
    import __builtin__

def _swig_setattr_nondynamic(self, class_type, name, value, static=1):
    if (name == "thisown"):
        return self.this.own(value)
    if (name == "this"):
        if type(value).__name__ == 'SwigPyObject':
            self.__dict__[name] = value
            return
    method = class_type.__swig_setmethods__.get(name, None)
    if method:
        return method(self, value)
    if (not static):
        object.__setattr__(self, name, value)
    else:
        raise AttributeError("You cannot add attributes to %s" % self)


def _swig_setattr(self, class_type, name, value):
    return _swig_setattr_nondynamic(self, class_type, name, value, 0)


def _swig_getattr(self, class_type, name):
    if (name == "thisown"):
        return self.this.own()
    method = class_type.__swig_getmethods__.get(name, None)
    if method:
        return method(self)
    raise AttributeError("'%s' object has no attribute '%s'" % (class_type.__name__, name))


def _swig_repr(self):
    try:
        strthis = "proxy of " + self.this.__repr__()
    except __builtin__.Exception:
        strthis = ""
    return "<%s.%s; %s >" % (self.__class__.__module__, self.__class__.__name__, strthis,)


def _swig_setattr_nondynamic_method(set):
    def set_attr(self, name, value):
        if (name == "thisown"):
            return self.this.own(value)
        if hasattr(self, name) or (name == "this"):
            set(self, name, value)
        else:
            raise AttributeError("You cannot add attributes to %s" % self)
    return set_attr


try:
    import weakref
    weakref_proxy = weakref.proxy
except __builtin__.Exception:
    weakref_proxy = lambda x: x


OEComponent_Interaction = _oeszmap.OEComponent_Interaction
OEComponent_PSolv = _oeszmap.OEComponent_PSolv
OEComponent_WSolv = _oeszmap.OEComponent_WSolv
OEComponent_VDW = _oeszmap.OEComponent_VDW
OEComponent_ProbeBurial = _oeszmap.OEComponent_ProbeBurial
OEComponent_NumTypes = _oeszmap.OEComponent_NumTypes
OEEnsemble_Interaction = _oeszmap.OEEnsemble_Interaction
OEEnsemble_PSolv = _oeszmap.OEEnsemble_PSolv
OEEnsemble_WSolv = _oeszmap.OEEnsemble_WSolv
OEEnsemble_VDW = _oeszmap.OEEnsemble_VDW
OEEnsemble_ProbeBurial = _oeszmap.OEEnsemble_ProbeBurial
OEEnsemble_InteractionPlusVDW = _oeszmap.OEEnsemble_InteractionPlusVDW
OEEnsemble_OrderParam = _oeszmap.OEEnsemble_OrderParam
OEEnsemble_CalcPoint = _oeszmap.OEEnsemble_CalcPoint
OEEnsemble_Mask = _oeszmap.OEEnsemble_Mask
OEEnsemble_NeutralDiffDeltaH = _oeszmap.OEEnsemble_NeutralDiffDeltaH
OEEnsemble_NeutralDiffTDeltaS = _oeszmap.OEEnsemble_NeutralDiffTDeltaS
OEEnsemble_NeutralDiffDeltaG = _oeszmap.OEEnsemble_NeutralDiffDeltaG
OEEnsemble_NeutralDeltaH = _oeszmap.OEEnsemble_NeutralDeltaH
OEEnsemble_NeutralTDeltaS = _oeszmap.OEEnsemble_NeutralTDeltaS
OEEnsemble_NeutralDeltaG = _oeszmap.OEEnsemble_NeutralDeltaG
OEEnsemble_VacuumDiffDeltaH = _oeszmap.OEEnsemble_VacuumDiffDeltaH
OEEnsemble_VacuumDiffDeltaG = _oeszmap.OEEnsemble_VacuumDiffDeltaG
OEEnsemble_DeltaH = _oeszmap.OEEnsemble_DeltaH
OEEnsemble_TDeltaS = _oeszmap.OEEnsemble_TDeltaS
OEEnsemble_DeltaG = _oeszmap.OEEnsemble_DeltaG
OEEnsemble_NumTypes = _oeszmap.OEEnsemble_NumTypes

OEEnsemble_Default = OEEnsemble_NeutralDiffDeltaG

import openeye.oechem as oechem
class OESzmapEngineOptions(object):
    """Proxy of C++ OESzmap::OESzmapEngineOptions class."""

    thisown = _swig_property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc='The membership flag')
    __repr__ = _swig_repr
    __swig_destroy__ = _oeszmap.delete_OESzmapEngineOptions
    __del__ = lambda self: None

    def __init__(self, *args):
        """
        __init__(OESzmap::OESzmapEngineOptions self) -> OESzmapEngineOptions
        __init__(OESzmap::OESzmapEngineOptions self, OESzmapEngineOptions rhs) -> OESzmapEngineOptions
        """
        this = _oeszmap.new_OESzmapEngineOptions(*args)
        try:
            self.this.append(this)
        except __builtin__.Exception:
            self.this = this

    def SetMaskCutoff(self, cutoff: 'double') -> "OESzmap::OESzmapEngineOptions &":
        """SetMaskCutoff(OESzmapEngineOptions self, double cutoff) -> OESzmapEngineOptions"""
        return _oeszmap.OESzmapEngineOptions_SetMaskCutoff(self, cutoff)


    def GetMaskCutoff(self) -> "double":
        """GetMaskCutoff(OESzmapEngineOptions self) -> double"""
        return _oeszmap.OESzmapEngineOptions_GetMaskCutoff(self)


    def SetProbe(self, numOrientations: 'unsigned int') -> "OESzmap::OESzmapEngineOptions &":
        """SetProbe(OESzmapEngineOptions self, unsigned int numOrientations) -> OESzmapEngineOptions"""
        return _oeszmap.OESzmapEngineOptions_SetProbe(self, numOrientations)


    def GetProbe(self) -> "OEChem::OEMCMolBase const &":
        """GetProbe(OESzmapEngineOptions self) -> OEMCMolBase"""
        return _oeszmap.OESzmapEngineOptions_GetProbe(self)


    def GetProbeMol(self, outputMol: 'OEMolBase', orientation: 'unsigned int'=0) -> "void":
        """
        GetProbeMol(OESzmapEngineOptions self, OEMolBase outputMol, unsigned int orientation=0)
        GetProbeMol(OESzmapEngineOptions self, OEMolBase outputMol)
        """
        return _oeszmap.OESzmapEngineOptions_GetProbeMol(self, outputMol, orientation)


    def NumOrientations(self) -> "unsigned int":
        """NumOrientations(OESzmapEngineOptions self) -> unsigned int"""
        return _oeszmap.OESzmapEngineOptions_NumOrientations(self)


    def GetProbeName(self) -> "char const *":
        """GetProbeName(OESzmapEngineOptions self) -> char const *"""
        return _oeszmap.OESzmapEngineOptions_GetProbeName(self)

OESzmapEngineOptions_swigregister = _oeszmap.OESzmapEngineOptions_swigregister
OESzmapEngineOptions_swigregister(OESzmapEngineOptions)

class OESzmapEngine(object):
    """Proxy of C++ OESzmap::OESzmapEngine class."""

    thisown = _swig_property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc='The membership flag')
    __repr__ = _swig_repr
    __swig_destroy__ = _oeszmap.delete_OESzmapEngine
    __del__ = lambda self: None

    def __init__(self, *args):
        """
        __init__(OESzmap::OESzmapEngine self, OESzmapEngineOptions opt) -> OESzmapEngine
        __init__(OESzmap::OESzmapEngine self) -> OESzmapEngine
        __init__(OESzmap::OESzmapEngine self, OEMolBase context, OESzmapEngineOptions opt) -> OESzmapEngine
        __init__(OESzmap::OESzmapEngine self, OEMolBase context) -> OESzmapEngine
        __init__(OESzmap::OESzmapEngine self, OESzmapEngine rhs) -> OESzmapEngine
        """
        this = _oeszmap.new_OESzmapEngine(*args)
        try:
            self.this.append(this)
        except __builtin__.Exception:
            self.this = this

    def GetOptions(self) -> "OESzmap::OESzmapEngineOptions const &":
        """GetOptions(OESzmapEngine self) -> OESzmapEngineOptions"""
        return _oeszmap.OESzmapEngine_GetOptions(self)


    def SetContext(self, context: 'OEMolBase') -> "bool":
        """SetContext(OESzmapEngine self, OEMolBase context) -> bool"""
        return _oeszmap.OESzmapEngine_SetContext(self, context)


    def GetContext(self) -> "OEChem::OEMolBase const &":
        """GetContext(OESzmapEngine self) -> OEMolBase"""
        return _oeszmap.OESzmapEngine_GetContext(self)


    def CheckAtomTypes(self) -> "bool":
        """CheckAtomTypes(OESzmapEngine self) -> bool"""
        return _oeszmap.OESzmapEngine_CheckAtomTypes(self)


    def IsValid(self):
      return _oeszmap.OESzmapEngine___nonzero__(self)


OESzmapEngine_swigregister = _oeszmap.OESzmapEngine_swigregister
OESzmapEngine_swigregister(OESzmapEngine)

class OESzmapResults(object):
    """Proxy of C++ OESzmap::OESzmapResults class."""

    thisown = _swig_property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc='The membership flag')
    __repr__ = _swig_repr
    __swig_destroy__ = _oeszmap.delete_OESzmapResults
    __del__ = lambda self: None

    def __init__(self, *args):
        """
        __init__(OESzmap::OESzmapResults self) -> OESzmapResults
        __init__(OESzmap::OESzmapResults self, OESzmapResults rhs) -> OESzmapResults
        """
        this = _oeszmap.new_OESzmapResults(*args)
        try:
            self.this.append(this)
        except __builtin__.Exception:
            self.this = this

    def IsValid(self):
      return _oeszmap.OESzmapResults___nonzero__(self)



    def Clear(self) -> "void":
        """Clear(OESzmapResults self)"""
        return _oeszmap.OESzmapResults_Clear(self)


    def GetEnsembleValue(self, ensembleType: 'unsigned int') -> "double":
        """GetEnsembleValue(OESzmapResults self, unsigned int ensembleType) -> double"""
        return _oeszmap.OESzmapResults_GetEnsembleValue(self, ensembleType)


    def GetComponent(self, *args) -> "bool":
        """
        GetComponent(OESzmapResults self, unsigned int componentType) -> OESystem::OEIterBase< double >
        GetComponent(OESzmapResults self, double * compArray, unsigned int componentType) -> bool
        """
        return _oeszmap.OESzmapResults_GetComponent(self, *args)


    def GetProbabilities(self, *args) -> "bool":
        """
        GetProbabilities(OESzmapResults self) -> OESystem::OEIterBase< double >
        GetProbabilities(OESzmapResults self, double * probArray) -> bool
        """
        return _oeszmap.OESzmapResults_GetProbabilities(self, *args)


    def GetProbabilityOrder(self, *args) -> "bool":
        """
        GetProbabilityOrder(OESzmapResults self) -> OESystem::OEIterBase< unsigned int >
        GetProbabilityOrder(OESzmapResults self, unsigned int * orderArray) -> bool
        """
        return _oeszmap.OESzmapResults_GetProbabilityOrder(self, *args)


    def PlaceProbeMol(self, outputMol: 'OEMolBase', orientation: 'unsigned int'=0, annotate: 'bool'=True) -> "bool":
        """
        PlaceProbeMol(OESzmapResults self, OEMolBase outputMol, unsigned int orientation=0, bool annotate=True) -> bool
        PlaceProbeMol(OESzmapResults self, OEMolBase outputMol, unsigned int orientation=0) -> bool
        PlaceProbeMol(OESzmapResults self, OEMolBase outputMol) -> bool
        """
        return _oeszmap.OESzmapResults_PlaceProbeMol(self, outputMol, orientation, annotate)


    def PlaceProbeSet(self, *args) -> "double":
        """
        PlaceProbeSet(OESzmapResults self, OEMCMolBase probeSet, double probCutoff, bool clear=True) -> double
        PlaceProbeSet(OESzmapResults self, OEMCMolBase probeSet, double probCutoff) -> double
        PlaceProbeSet(OESzmapResults self, OEMCMolBase probeSet, unsigned int maxConfs=0, bool clear=True) -> double
        PlaceProbeSet(OESzmapResults self, OEMCMolBase probeSet, unsigned int maxConfs=0) -> double
        PlaceProbeSet(OESzmapResults self, OEMCMolBase probeSet) -> double
        """
        return _oeszmap.OESzmapResults_PlaceProbeSet(self, *args)


    def PlaceNewAtom(self, *args) -> "OEChem::OEAtomBase *":
        """
        PlaceNewAtom(OESzmapResults self, OEMolBase mol, unsigned int element) -> OEAtomBase
        PlaceNewAtom(OESzmapResults self, OEMolBase mol) -> OEAtomBase
        """
        return _oeszmap.OESzmapResults_PlaceNewAtom(self, *args)


    def GetCoords(self, *args) -> "bool":
        """
        GetCoords(OESzmapResults self, double * xyz) -> bool
        GetCoords(OESzmapResults self, float * xyz) -> bool
        """
        return _oeszmap.OESzmapResults_GetCoords(self, *args)


    def NumOrientations(self) -> "unsigned int":
        """NumOrientations(OESzmapResults self) -> unsigned int"""
        return _oeszmap.OESzmapResults_NumOrientations(self)

OESzmapResults_swigregister = _oeszmap.OESzmapResults_swigregister
OESzmapResults_swigregister(OESzmapResults)


def OEIsClashing(*args) -> "bool":
    """
    OEIsClashing(OESzmapEngine szmap, double const * xyz) -> bool
    OEIsClashing(OESzmapEngine szmap, float const * xyz) -> bool
    """
    return _oeszmap.OEIsClashing(*args)

def OECalcSzmapValue(*args) -> "double":
    """
    OECalcSzmapValue(OESzmapEngine szmap, double const * xyz, unsigned int ensembleType) -> double
    OECalcSzmapValue(OESzmapEngine szmap, double const * xyz) -> double
    OECalcSzmapValue(OESzmapEngine szmap, float const * xyz, unsigned int ensembleType) -> double
    OECalcSzmapValue(OESzmapEngine szmap, float const * xyz) -> double
    """
    return _oeszmap.OECalcSzmapValue(*args)

def OECalcSzmapResults(*args) -> "bool":
    """
    OECalcSzmapResults(OESzmapResults results, OESzmapEngine szmap, double const * xyz) -> bool
    OECalcSzmapResults(OESzmapResults results, OESzmapEngine szmap, float const * xyz) -> bool
    """
    return _oeszmap.OECalcSzmapResults(*args)

def OEGetEnsembleName(ensembleType: 'unsigned int', longName: 'bool'=False) -> "char const *":
    """
    OEGetEnsembleName(unsigned int ensembleType, bool longName=False) -> char const
    OEGetEnsembleName(unsigned int ensembleType) -> char const *
    """
    return _oeszmap.OEGetEnsembleName(ensembleType, longName)

def OEGetComponentName(componentType: 'unsigned int') -> "char const *":
    """OEGetComponentName(unsigned int componentType) -> char const *"""
    return _oeszmap.OEGetComponentName(componentType)
OE_OESZMAP_VERSION = _oeszmap.OE_OESZMAP_VERSION

def OESzmapGetRelease() -> "char const *":
    """OESzmapGetRelease() -> char const *"""
    return _oeszmap.OESzmapGetRelease()

def OESzmapGetVersion() -> "unsigned int":
    """OESzmapGetVersion() -> unsigned int"""
    return _oeszmap.OESzmapGetVersion()

def OESzmapGetArch() -> "char const *":
    """OESzmapGetArch() -> char const *"""
    return _oeszmap.OESzmapGetArch()

def OESzmapGetPlatform() -> "char const *":
    """OESzmapGetPlatform() -> char const *"""
    return _oeszmap.OESzmapGetPlatform()

def OESzmapIsLicensed(feature: 'char const *'=None, expdate: 'unsigned int *'=None) -> "bool":
    """
    OESzmapIsLicensed(char const * feature=None, unsigned int * expdate=None) -> bool
    OESzmapIsLicensed(char const * feature=None) -> bool
    OESzmapIsLicensed() -> bool
    """
    return _oeszmap.OESzmapIsLicensed(feature, expdate)

def OESzmapGetLicensee(*args) -> "std::string":
    """
    OESzmapGetLicensee(std::string & licensee) -> bool
    OESzmapGetLicensee() -> std::string
    """
    return _oeszmap.OESzmapGetLicensee(*args)

def OESzmapGetSite(*args) -> "std::string":
    """
    OESzmapGetSite(std::string & site) -> bool
    OESzmapGetSite() -> std::string
    """
    return _oeszmap.OESzmapGetSite(*args)





#!/usr/bin/env python
# (C) 2017 OpenEye Scientific Software Inc. All rights reserved.
#
# TERMS FOR USE OF SAMPLE CODE The software below ("Sample Code") is
# provided to current licensees or subscribers of OpenEye products or
# SaaS offerings (each a "Customer").
# Customer is hereby permitted to use, copy, and modify the Sample Code,
# subject to these terms. OpenEye claims no rights to Customer's
# modifications. Modification of Sample Code is at Customer's sole and
# exclusive risk. Sample Code may require Customer to have a then
# current license or subscription to the applicable OpenEye offering.
# THE SAMPLE CODE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
# EXPRESS OR IMPLIED.  OPENEYE DISCLAIMS ALL WARRANTIES, INCLUDING, BUT
# NOT LIMITED TO, WARRANTIES OF MERCHANTABILITY, FITNESS FOR A
# PARTICULAR PURPOSE AND NONINFRINGEMENT. In no event shall OpenEye be
# liable for any damages or liability in connection with the Sample Code
# or its use.

import sys
from openeye import oechem
from openeye import oedepict
from openeye import oegrapheme


###############################################################
# USED TO GENERATE CODE SNIPPETS FOR THE GRAPHEME DOCUMENTATION
###############################################################

def ImportProtein(filename):

    ifs = oechem.oemolistream()
    if not ifs.open(filename):
        oechem.OEThrow.Fatal("Unable to open %s for reading" % filename)

    mol = oechem.OEGraphMol()
    if not oechem.OEReadMolecule(ifs, mol):
        oechem.OEThrow.Fatal("Unable to read molecule in %s" % filename)

    return mol


if len(sys.argv) != 2:
    oechem.OEThrow.Usage("%s <protein>" % sys.argv[0])

protein = ImportProtein(sys.argv[1])

# @ <SNIPPET-RENDER-RAMA>
image = oedepict.OEImage(800, 600)

ramaplot = oegrapheme.OERamachandranPlot()
ramaplot.AddMolecule(protein)

oegrapheme.OERenderRamachandranPlot(image, ramaplot)
# @ </SNIPPET-RENDER-RAMA>
oedepict.OEDrawCurvedBorder(image, oedepict.OELightGreyPen, 10.0)
oedepict.OEWriteImage("RenderRamachandranPlot.svg", image)

# @ <SNIPPET-RENDER-RAMA-GENERAL>
image = oedepict.OEImage(800, 600)

ramaplot = oegrapheme.OERamachandranPlot()
ramaplot.AddMolecule(protein)

oegrapheme.OERenderRamachandranPlot(image, ramaplot, oechem.OERamaType_General)
# @ </SNIPPET-RENDER-RAMA-GENERAL>

oedepict.OEDrawCurvedBorder(image, oedepict.OELightGreyPen, 10.0)
oedepict.OEWriteImage("RenderRamachandranPlot-General.png", image)
oedepict.OEAddInteractiveIcon(image, oedepict.OEIconLocation_TopRight, 0.50)
oedepict.OEWriteImage("RenderRamachandranPlot-General.svg", image)



#!/opt/anaconda1anaconda2anaconda3/bin/python
# (C) 2017 OpenEye Scientific Software Inc. All rights reserved.
#
# TERMS FOR USE OF SAMPLE CODE The software below ("Sample Code") is
# provided to current licensees or subscribers of OpenEye products or
# SaaS offerings (each a "Customer").
# Customer is hereby permitted to use, copy, and modify the Sample Code,
# subject to these terms. OpenEye claims no rights to Customer's
# modifications. Modification of Sample Code is at Customer's sole and
# exclusive risk. Sample Code may require Customer to have a then
# current license or subscription to the applicable OpenEye offering.
# THE SAMPLE CODE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
# EXPRESS OR IMPLIED.  OPENEYE DISCLAIMS ALL WARRANTIES, INCLUDING, BUT
# NOT LIMITED TO, WARRANTIES OF MERCHANTABILITY, FITNESS FOR A
# PARTICULAR PURPOSE AND NONINFRINGEMENT. In no event shall OpenEye be
# liable for any damages or liability in connection with the Sample Code
# or its use.

import sys
from math import log10
from math import sqrt
from math import pow

from openeye import oechem
from openeye import oestats
from openeye import oedepict


def GetColorDict():
    colorMap = {}
    colorMap["red"] = oechem.OERed
    colorMap["green"] = oechem.OEGreen
    colorMap["blue"] = oechem.OEBlue
    colorMap["yellow"] = oechem.OEYellow
    colorMap["cyan"] = oechem.OECyan
    colorMap["magenta"] = oechem.OEMagenta
    colorMap["orange"] = oechem.OEOrange
    colorMap["pink"] = oechem.OEPink
    colorMap["grey"] = oechem.OEPurple
    colorMap["royalblue"] = oechem.OERoyalBlue
    colorMap["olivebrown"] = oechem.OEOliveBrown
    colorMap["olivegreen"] = oechem.OEOliveGreen
    colorMap["oliveGrey"] = oechem.OEOliveGrey
    colorMap["limegreen"] = oechem.OELimeGreen
    colorMap["darkblue"] = oechem.OEDarkBlue
    colorMap["darkgreen"] = oechem.OEDarkGreen
    colorMap["darkblue"] = oechem.OEDarkBlue
    colorMap["darkyellow"] = oechem.OEDarkYellow
    colorMap["darkcyan"] = oechem.OEDarkCyan
    colorMap["darkmagenta"] = oechem.OEDarkMagenta
    colorMap["darkorange"] = oechem.OEDarkOrange
    colorMap["darkgrey"] = oechem.OEDarkGrey
    colorMap["darkrose"] = oechem.OEDarkRose
    colorMap["darkbrown"] = oechem.OEDarkBrown
    colorMap["darksalmon"] = oechem.OEDarkSalmon
    colorMap["darkpurple"] = oechem.OEDarkPurple
    colorMap["mediumbrown"] = oechem.OEMediumBrown
    colorMap["mediumBlue"] = oechem.OEMediumBlue
    colorMap["mediumyellow"] = oechem.OEMediumYellow
    colorMap["mediumgreen"] = oechem.OEMediumGreen
    colorMap["mediumorange"] = oechem.OEMediumOrange
    colorMap["mediumpurple"] = oechem.OEMediumPurple
    colorMap["mediumsalmon"] = oechem.OEMediumSalmon
    colorMap["lightblue"] = oechem.OELightBlue
    colorMap["lightgrey"] = oechem.OELightGrey
    colorMap["lightpurple"] = oechem.OELightPurple
    colorMap["lightsalmon"] = oechem.OELightSalmon
    colorMap["lightbrown"] = oechem.OELightBrown
    colorMap["lightorange"] = oechem.OELightOrange
    colorMap["lightgreen"] = oechem.OELightGreen
    colorMap["bluetint"] = oechem.OEBlueTint
    colorMap["brown"] = oechem.OEBrown
    colorMap["mandarin"] = oechem.OEMandarin
    colorMap["greenblue"] = oechem.OEGreenBlue
    colorMap["greentint"] = oechem.OEGreenTint
    colorMap["hotpink"] = oechem.OEHotPink
    colorMap["pinktint"] = oechem.OEPinkTint
    colorMap["redorange"] = oechem.OERedOrange
    colorMap["seagreen"] = oechem.OESeaGreen
    colorMap["skyblue"] = oechem.OESkyBlue
    colorMap["violet"] = oechem.OEViolet
    colorMap["yellowtint"] = oechem.OEYellowTint
    colorMap["copper"] = oechem.OECopper
    colorMap["gold"] = oechem.OEGold
    colorMap["silver"] = oechem.OESilver
    colorMap["pewter"] = oechem.OEPewter
    colorMap["brass"] = oechem.OEBrass
    return colorMap


def OEAddParameterColors(itf, flag):
    param = itf.GetParameter(flag)
    colorMap = GetColorDict()
    for key in colorMap:
        param.AddLegalValue(key)


def OETextToColor(text):
    colorMap = GetColorDict()
    return colorMap[text]


def OEGetFilename(itf, flag):
    prefix = itf.GetString("-prefix")
    param = itf.GetParameter(flag)
    if param.GetHasValue():
        return itf.GetString(flag)
    else:
        return prefix + "_" + itf.GetString(flag)


def OEIsUnmeasured(itf, val):
    if itf.HasDouble("-unmeasured_greater"):
        uVal = itf.GetDouble("-unmeasured_greater")
        if itf.GetBool("-krige_log"):
            uVal = log10(uVal)
        if val > uVal:
            return True

    if itf.HasDouble("-unmeasured_less"):
        uVal = itf.GetDouble("-unmeasured_less")
        if itf.GetBool("-krige_log"):
            uVal = log10(uVal)
        if val < uVal:
            return True
    iVal = 0
    while itf.HasDouble("-unmeasured_values", iVal):
        uVal = itf.GetDouble("-unmeasured_values", iVal)
        if itf.GetBool("-krige_log"):
            uVal = log10(uVal)
        if val == uVal:
            return True
        iVal += 1
    return False


def main(argv=[__name__]):
    itf = oechem.OEInterface()
    oechem.OEConfigure(itf, Interface)
    OEAddParameterColors(itf, "-atom_contribution_positive_color")
    OEAddParameterColors(itf, "-atom_contribution_negative_color")
    OEAddParameterColors(itf, "-classification_colors")
    if not oechem.OEParseCommandLine(itf, argv):
        return 1

    # Figure out output file name
    outFile = OEGetFilename(itf, "-molecule_file")
    reportFile = OEGetFilename(itf, "-report_file")
    failTrainFile = OEGetFilename(itf, "-training_fail_file")
    failKrigeFile = OEGetFilename(itf, "-prediction_fail_file")
    settingsFile = OEGetFilename(itf, "-settings_file")

    # Write the settings file and splash to screen
    oechem.OEWriteSettings(itf, oechem.oeout, False)
    ofs = oechem.oeofstream(settingsFile)
    oechem.OEWriteSettings(itf, ofs, True)
    ofs.close()

    # Setup report options
    rOpts = oestats.OEKrigeReportOptions()
    if itf.HasString("-report_title"):
        rOpts.SetTitle(itf.GetString("-report_title"))
    if itf.HasString("-response_name"):
        rOpts.SetResponseName(itf.GetString("-response_name"))
        responseName = itf.GetString("-response_name")
    else:
        rOpts.SetResponseName(itf.GetString("-response_tag"))
        responseName = itf.GetString("-response_tag")
    if itf.HasString("-atom_contribution_negative_color"):
        color = OETextToColor(itf.GetString("-atom_contribution_negative_color"))
        rOpts.SetContributionNegativeColor(color)
    if itf.HasString("-atom_contribution_positive_color"):
        color = OETextToColor(itf.GetString("-atom_contribution_positive_color"))
        rOpts.SetContributionPositiveColor(color)
    iExtra = 0
    while itf.HasString("-report_tagged_data", iExtra):
        rOpts.PushSDProperty(itf.GetString("-report_tagged_data", iExtra))
        iExtra += 1
    iClass = 0
    while itf.HasDouble("-classification_boundries", iClass):
        boundry = itf.GetDouble("-classification_boundries", iClass)
        if itf.GetBool("-krige_log"):
            boundry = log10(boundry)
        rOpts.PushClassificationBoundry(boundry)
        iClass += 1
    iClass = 0
    while itf.HasString("-classification_colors", iClass):
        color = OETextToColor(itf.GetString("-classification_colors", iClass))
        rOpts.PushClassificationColor(color)
        iClass += 1
    if itf.GetBool("-hide_krige_details"):
        rOpts.SetShowKrigeDetails(False)
    else:
        rOpts.SetShowKrigeDetails(True)
    rOpts.SetUnlog(itf.GetBool("-krige_log"))
    rOpts.SetShowConfidence(itf.GetBool("-show_response_confidence"))
    rOpts.SetResponseSignificantFigures(itf.GetUnsignedInt("-report_significant_figures"))
    if itf.HasString("-atom_contribution_positive_label"):
        rOpts.SetContributionPositiveLabel(itf.GetString("-atom_contribution_positive_label"))
    if itf.HasString("-atom_contribution_negative_label"):
        rOpts.SetContributionNegativeLabel(itf.GetString("-atom_contribution_negative_label"))
    if itf.HasDouble("-atom_contribution_baseline_response"):
        baseline = itf.GetDouble("-atom_contribution_baseline_response")
        if itf.GetBool("-krige_log"):
            baseline = log10(baseline)
            rOpts.SetContributionBaseline(baseline)

    # Figure out the trend properties for universal kriging if we have them
    universalProps = oechem.OEMolPropertyList()
    iProp = 0
    while itf.HasString("-universal_prop", iProp):
        propStr = itf.GetString("-universal_prop", iProp)
        if propStr == "mw":
            universalProps.Add(oestats.OEMolecularWeightPropertyFxn())
            rOpts.PushProperty(oestats.OEMolecularWeightPropertyFxn(), "Molecular Weight")
        else:
            oechem.OEThrow.Error("Unknow property (%s) passed to -universal_prop" % propStr)
        iProp += 1

    # Setup the object for getting the response from the training molecules
    responseFxn = oechem.OEMolTaggedPropertyFxn(itf.GetString("-response_tag"))
    if itf.GetBool("-krige_log"):
        responseFxn = oestats.OEMolLog10PropertyFxn(responseFxn)

    # Construct the krige
    if itf.HasUnsignedInt("-local_krige"):
        opts = oestats.OELocalKrigeOptions()
        opts.SetNumLocal(itf.GetUnsignedInt("-local_krige"))
    else:
        opts = oestats.OEGlobalKrigeOptions()

    # Set if the distance function is stereo aware
    distOpts = oestats.OEDefaultKrigeDistanceOptions()
    distOpts.SetStereoAware(not itf.GetBool("-ignore_stereo"))

    krige = oestats.OEMolKrige(distOpts, universalProps, opts)

    # Add the training molecules to the Krige
    print("Reading in training molecules")
    sw = oechem.OEStopwatch()
    failStr = None
    numTrain = 0
    numTrainFail = 0
    numTrainUnmeasured = 0
    numTrainMeasured = 0
    for trainFile in itf.GetStringList("-train"):
        imstr = oechem.oemolistream(trainFile)
        for mol in imstr.GetOEMols():
            success = False
            # measured = True
            if responseFxn.Has(mol):
                response = responseFxn.Get(mol)
                if OEIsUnmeasured(itf, response):
                    numTrainUnmeasured += 1
                    # measured = False
                    success = krige.AddUnmeasuredTraining(mol, response)
                else:
                    numTrainMeasured += 1
                    success = krige.AddTraining(mol, response)
                numTrain += 1
            if not success:
                numTrainFail += 1
                if failStr is None:
                    failStr = oechem.oemolostream(failTrainFile)
                oechem.OEWriteMolecule(failStr, mol)
            if sw.Elapsed() > 10.0:
                sw.Start()
                if numTrainFail != 0:
                    print("So far added %d training molecules, and of those \
                          %d unmeasured are unmeasured.  "
                          "%d input molecules are missing response data or \
                          universal krige properties."
                          % (numTrain, numTrainUnmeasured, numTrainFail))
                else:
                    print("So far added %d training molecules, and of those \
                          %d unmeasured are unmeasured."
                          % (numTrain, numTrainUnmeasured))
        imstr.close()
    if failStr is not None:
        failStr.close()
        print("Training failed molecules written to %s" % failTrainFile)
    if numTrainFail != 0:
        print("Added %d training molecules, and of those %d unmeasured are unmeasured.  "
              "%d input molecules are missing response data or universal krige properties."
              % (numTrain, numTrainUnmeasured, numTrainFail))
    else:
        print("Added %d training molecules, and of those %d unmeasured are unmeasured."
              % (numTrain, numTrainUnmeasured))

    # Train the Krige on the molecules we added
    print("Training krige model")
    if krige.Train():
        print("Training successful")
    else:
        print("Training failed, aborting")
        return

    # Krige for MW of the test molecules, and compare to actual MW
    krigeTag = "Krige(%s)" % responseName
    upperTag = "Krige(%s) 95%% confidence upper" % responseName
    lowerTag = "Krige(%s) 95%% confidence lower" % responseName

    print("Predicting %s of input molecules" % responseName)
    numKrige = 0
    numKrigeFail = 0
    outstr = oechem.oemolostream(outFile)
    multi = oedepict.OEMultiPageImageFile(oedepict.OEPageOrientation_Landscape,
                                          oedepict.OEPageSize_US_Letter)
    failStr = None
    sw.Start()
    for molFile in itf.GetStringList("-in"):
        imstr = oechem.oemolistream(molFile)
        for mol in imstr.GetOEMols():
            result = krige.GetResult(mol)
            success = True
            if result.Valid():
                response = result.GetResponse()
                conf95 = 1.96*sqrt(result.GetVariance())
                upper95 = response + conf95
                lower95 = response - conf95
                if itf.GetBool("-krige_log"):
                    response = pow(10.0, response)
                    upper95 = pow(10.0, upper95)
                    lower95 = pow(10.0, lower95)
                oechem.OESetSDData(mol, krigeTag, str(response))
                oechem.OESetSDData(mol, upperTag, str(upper95))
                oechem.OESetSDData(mol, lowerTag, str(lower95))
                if not itf.GetBool("-no_report"):
                    oestats.OEKrigeRenderReport(multi.NewPage(), result, mol, rOpts)
                oechem.OEWriteMolecule(outstr, mol)
            else:
                success = False
            numKrige += 1
            if not success:
                numKrigeFail += 1
                failStr = oechem.oemolostream(failKrigeFile)
                oechem.OEWriteMolecule(failStr, mol)
            if sw.Elapsed() > 10.0:
                print("Kriging predicted %d molecules (%d failures) so far"
                      % (numKrige, numKrigeFail))
                sw.Start()
        imstr.close()
    outstr.close()
    if failStr is not None:
        failStr.close()
    print("Kriging predicted %d molecules (%d failures)" % (numKrige, numKrigeFail))

    if not itf.GetBool("-no_report"):
        print("Writing report to %s" % reportFile)
        oedepict.OEWriteMultiPageImage(reportFile, multi)
    print("Finished")

    return 0


Interface = """
!CATEGORY "Input" 1

  !PARAMETER -param 0
    !TYPE param_file
    !REQUIRED false
    !SIMPLE false
    !BRIEF Parameter file
  !END

  !PARAMETER -in 1
    !TYPE string
    !LIST true
    !REQUIRED true
    !BRIEF Input molecules to predict
  !END

  !PARAMETER -training
    !ALIAS -train
    !TYPE string
    !LIST true
    !REQUIRED true
    !LEGAL_VALUE *.oeb.gz
    !LEGAL_VALUE *.sdf.gz
    !LEGAL_VALUE *.oeb
    !LEGAL_VALUE *.sdf
    !BRIEF Training molecules for the krige.  \
Response values should be tagged to SD or generic data (see -response_tag).
  !END

!END

!CATEGORY Settings 2
  !PARAMETER -response_tag 1
    !ALIAS -tag
    !ALIAS -response_tag
    !TYPE string
    !REQUIRED true
    !BRIEF SD or generic data tag on the training molecules the Krige will predict.
  !END

  !PARAMETER -krige_log 2
    !ALIAS -log
    !TYPE bool
    !DEFAULT false
    !SIMPLE true
    !BRIEF Krige on the log of the property specified by the -response_tag. \
Commonly used when predicting activity concentration (e.g. IC50).
  !END

  !PARAMETER -local_krige 3
    !ALIAS -krige_local
    !ALIAS -num_local
    !TYPE unsigned
    !SIMPLE true
    !DEFAULT 0
    !BRIEF Number of nearest training molecules to use in the krige. \
           Setting 0 uses all, i.e., global kriging.
  !END

  !PARAMETER -response_name 4
    !ALIAS -name
    !TYPE string
    !REQUIRED false
    !SIMPLE false
    !BRIEF Name of the response.  If not specified the setting of -response_tag will be used.
  !END

  !PARAMETER -ignore_stereo 5
    !TYPE bool
    !DEFAULT false
    !SIMPLE false
    !BRIEF If true the stereoness of atoms will be ignored \
           in the 2d distance function the krige uses.
  !END

  !CATEGORY "Specifying Unmeasured Responses" 6

    !PARAMETER -unmeasured_values 1
      !ALIAS -unmeasured
      !TYPE double
      !REQUIRED false
      !LIST true
      !SIMPLE false
      !BRIEF Response values that will be considered unmeasured.
    !END

    !PARAMETER -unmeasured_greater 2
      !TYPE double
      !REQUIRED false
      !SIMPLE false
      !BRIEF Response values greater than this value will be considered unmeasured
    !END

    !PARAMETER -unmeasured_less 2
      !TYPE double
      !REQUIRED false
      !SIMPLE false
      !BRIEF Response values less than this value will be considered unmeasured
    !END

  !END

  !CATEGORY "Universal kriging" 7

    !BRIEF Universal kriging flags.  They can be used in combination.

    !PARAMETER -universal_tag
      !ALIAS -utag
      !TYPE string
      !LIST true
      !REQUIRED false
      !SIMPLE false
      !BRIEF SD or generic data tags to use as trend properties for universal kriging.
    !END

    !PARAMETER -universal_tag_log
      !ALIAS -utag_log
      !TYPE string
      !LIST true
      !REQUIRED false
      !SIMPLE false
      !BRIEF Same as -universal_tag, except that the log of the values will be used.
    !END

    !PARAMETER -universal_prop
      !ALIAS -uprop
      !TYPE string
      !LIST true
      !REQUIRED false
      !SIMPLE false
      !LEGAL_VALUE mw
      !BRIEF Calculated properties to use as trend properties for universal kriging
    !END

  !END

  !CATEGORY "Report Options" 8

    !PARAMETER -no_report 0
      !TYPE bool
      !DEFAULT false
      !BRIEF Supress creating a report PDF file.
    !END

    !PARAMETER -report_title 1
      !ALIAS -title
      !TYPE string
      !SIMPLE false
      !BRIEF Title that will be printed on the top of each page of the report.
    !END

    !PARAMETER -report_significant_figures 3
      !ALIAS -sigfigs
      !TYPE unsigned
      !SIMPLE false
      !DEFAULT 3
      !BRIEF Number of significant figures to report the response in on the report.
    !END

    !PARAMETER -show_response_confidence 4
      !ALIAS -conf95
      !TYPE bool
      !DEFAULT false
      !SIMPLE false
      !BRIEF Show the 95% confidence interval of the response on the report.
    !END

    !PARAMETER -report_tagged_data 2
      !ALIAS -extra_tags
      !TYPE string
      !REQUIRED false
      !SIMPLE false
      !BRIEF Extra SD/genertic data to include on the report. \
             (Not used by the calculation).
    !END

    !PARAMETER -atom_contribution_positive_color 4
      !ALIAS -positive_color
      !ALIAS -pos_color
      !TYPE string
      !REQUIRED false
      !SIMPLE false
      !BRIEF Color of positive atom contributions on the krige report
    !END

    !PARAMETER -atom_contribution_negative_color 5
      !ALIAS -negative_color
      !ALIAS -neg_color
      !TYPE string
      !REQUIRED false
      !SIMPLE false
      !BRIEF Color of positive atom contributions on the krige report
    !END

    !PARAMETER -atom_contribution_positive_label 6
      !ALIAS -positive_label
      !ALIAS -pos_label
      !TYPE string
      !SIMPLE false
      !REQUIRED false
      !BRIEF Legend label for atoms that contribute positively to the response
    !END

    !PARAMETER -atom_contribution_negative_label 7
      !ALIAS -negative_label
      !ALIAS -neg_label
      !TYPE string
      !SIMPLE false
      !REQUIRED false
      !BRIEF Legend label for atoms that contribute negatively to the response
    !END

    !PARAMETER -atom_contribution_baseline_response 8
      !ALIAS -baseline_response
      !TYPE double
      !SIMPLE false
      !REQUIRED false
      !BRIEF Set the baseline response that is considered neutral for atom contributions.  \
If not specified the predicted response of each molecule is used for atom contributions.
    !END

    !PARAMETER -classification_boundries 9
      !ALIAS -class
      !TYPE double
      !REQUIRED false
      !SIMPLE false
      !LIST true
      !BRIEF Report result will be given in terms of classifcation defined by \
             these response boundry values.
    !END

    !PARAMETER -classification_colors 10
      !ALIAS -class_colors
      !LIST true
      !TYPE string
      !REQUIRED false
      !SIMPLE false
      !BRIEF User specification of the classification colors.  \
The order applies to the classifications is highest to lowest.
    !END

    !PARAMETER -hide_krige_details 11
      !ALIAS -hide_details
      !TYPE bool
      !SIMPLE false
      !DEFAULT false
      !BRIEF Hide the krige details in the report (variogram and model quality).
    !END

  !END

!END

!CATEGORY "Output" 5

  !PARAMETER -prefix 1
    !TYPE string
    !DEFAULT krige
    !SIMPLE true
    !BRIEF Prefix for output files
  !END

  !PARAMETER -molecule_file 2
    !ALIAS -mol_file
    !ALIAS -out
    !TYPE string
    !SIMPLE false
    !DEFAULT molecules.sdf
    !LEGAL_VALUE *.oeb.gz
    !LEGAL_VALUE *.sdf.gz
    !LEGAL_VALUE *.oeb
    !LEGAL_VALUE *.sdf
    !BRIEF Output molecule for molecules with krige predictions tagged to them
  !END

  !PARAMETER -report_file 3
    !ALIAS -report
    !TYPE string
    !DEFAULT report.pdf
    !LEGAL_VALUE *.pdf
    !SIMPLE false
    !BRIEF Report file
  !END

  !PARAMETER -training_fail_file 4
    !ALIAS -train_fail_file
    !TYPE string
    !DEFAULT training_fail.sdf
    !SIMPLE false
    !BRIEF Output file for training molecules that failed to be added to the Krige
  !END

  !PARAMETER -prediction_fail_file 5
    !ALIAS -predict_fail_file
    !TYPE string
    !DEFAULT prediction_fail.sdf
    !SIMPLE false
    !BRIEF Output files for molecules that the Krige failed to predict
  !END

  !PARAMETER -settings_file 6
    !TYPE string
    !DEFAULT settings.txt
    !SIMPLE false
    !BRIEF Output file with parameters settings for this run
  !END

!END

"""


if __name__ == "__main__":
    sys.exit(main(sys.argv))



# CONFIDENTIAL. (C) 2017 OpenEye Scientific Software Inc.
# All rights reserved.
# 
# ALL SOFTWARE BELOW IS PROPRIETARY AND CONFIDENTIAL TO OPENEYE
# SCIENTIFIC SOFTWARE INC., AND IS SUBJECT TO THE FULL PROTECTION OF
# COPYRIGHT AND TRADESECRET LAW.
# Copying or modifying this software is strictly prohibited and illegal.
# Using this software without a valid license from OpenEye is strictly
# prohibited and illegal.  De-obfuscating, de-minimizing, or any other
# attempt to reverse engineer or discover the workings of this software,
# is strictly prohibited. Even if software is exposed or visible, it is
# still proprietary and confidential and the above prohibitions apply.
# This software is NOT "Sample Code". For purposes of customization or
# interoperation with other software you must use Sample Code
# specifically labeled as such.
# Please contact OpenEye at eyesopen.com/legal if you have any questions
# about this warning.


# This file was automatically generated by SWIG (http://www.swig.org).
# Version 3.0.12
#
# Do not make changes to this file unless you know what you are doing--modify
# the SWIG interface file instead.

from sys import version_info as _swig_python_version_info

def swig_import_helper():
    from os.path import dirname
    import importlib.util

    spec = importlib.machinery.PathFinder().find_spec("_oechem", [dirname(__file__)])

    if spec is None:
        # OpenEye Import Statements
        spec = importlib.machinery.PathFinder().find_spec("libs",[dirname(__file__)])
    libs = importlib.util.module_from_spec(spec)

    import sys
    sys.modules[spec.name] = libs
    spec.loader.exec_module(libs)

    assert not sys.platform.startswith('win')

    _oeiupac = libs.OEGetModule('_oeiupac2715')
    return _oeiupac

_oeiupac = swig_import_helper()
del swig_import_helper
del _swig_python_version_info

try:
    _swig_property = property
except NameError:
    pass  # Python < 2.2 doesn't have 'property'.

try:
    import builtins as __builtin__
except ImportError:
    import __builtin__

def _swig_setattr_nondynamic(self, class_type, name, value, static=1):
    if (name == "thisown"):
        return self.this.own(value)
    if (name == "this"):
        if type(value).__name__ == 'SwigPyObject':
            self.__dict__[name] = value
            return
    method = class_type.__swig_setmethods__.get(name, None)
    if method:
        return method(self, value)
    if (not static):
        object.__setattr__(self, name, value)
    else:
        raise AttributeError("You cannot add attributes to %s" % self)


def _swig_setattr(self, class_type, name, value):
    return _swig_setattr_nondynamic(self, class_type, name, value, 0)


def _swig_getattr(self, class_type, name):
    if (name == "thisown"):
        return self.this.own()
    method = class_type.__swig_getmethods__.get(name, None)
    if method:
        return method(self)
    raise AttributeError("'%s' object has no attribute '%s'" % (class_type.__name__, name))


def _swig_repr(self):
    try:
        strthis = "proxy of " + self.this.__repr__()
    except __builtin__.Exception:
        strthis = ""
    return "<%s.%s; %s >" % (self.__class__.__module__, self.__class__.__name__, strthis,)


def _swig_setattr_nondynamic_method(set):
    def set_attr(self, name, value):
        if (name == "thisown"):
            return self.this.own(value)
        if hasattr(self, name) or (name == "this"):
            set(self, name, value)
        else:
            raise AttributeError("You cannot add attributes to %s" % self)
    return set_attr


try:
    import weakref
    weakref_proxy = weakref.proxy
except __builtin__.Exception:
    weakref_proxy = lambda x: x



def __no_op(*args) -> "void":
    return _oeiupac.__no_op(*args)
__no_op = _oeiupac.__no_op
import openeye.oechem as oechem
OENamStyle_NS_VERSION = _oeiupac.OENamStyle_NS_VERSION
OENamStyle_NS_COMMON = _oeiupac.OENamStyle_NS_COMMON
OENamStyle_NS_CAS = _oeiupac.OENamStyle_NS_CAS
OENamStyle_NS_OLD = _oeiupac.OENamStyle_NS_OLD
OENamStyle_NS_SYS = _oeiupac.OENamStyle_NS_SYS
OENamStyle_NS_ESTER = _oeiupac.OENamStyle_NS_ESTER
OENamStyle_NS_STEREO = _oeiupac.OENamStyle_NS_STEREO
OENamStyle_NS_DASH = _oeiupac.OENamStyle_NS_DASH
OENamStyle_NS_AMINE = _oeiupac.OENamStyle_NS_AMINE
OENamStyle_NS_RINGLOC = _oeiupac.OENamStyle_NS_RINGLOC
OENamStyle_NS_PERMIDX = _oeiupac.OENamStyle_NS_PERMIDX
OENamStyle_NS_IUPAC79 = _oeiupac.OENamStyle_NS_IUPAC79
OENamStyle_NS_IUPAC93 = _oeiupac.OENamStyle_NS_IUPAC93
OENamStyle_NS_AUTONOM = _oeiupac.OENamStyle_NS_AUTONOM
OENamStyle_NS_PSEUDOHAL = _oeiupac.OENamStyle_NS_PSEUDOHAL
OENamStyle_NS_ACDNAME = _oeiupac.OENamStyle_NS_ACDNAME
OENamStyle_NS_AMMONIO = _oeiupac.OENamStyle_NS_AMMONIO
OENamStyle_NS_PERMIDX2 = _oeiupac.OENamStyle_NS_PERMIDX2
OENamStyle_NS_1NLOC = _oeiupac.OENamStyle_NS_1NLOC
OENamStyle_NS_FLIPENH = _oeiupac.OENamStyle_NS_FLIPENH
OENamStyle_NS_MAX = _oeiupac.OENamStyle_NS_MAX
OECharSet_DEFAULT = _oeiupac.OECharSet_DEFAULT
OECharSet_ASCII = _oeiupac.OECharSet_ASCII
OECharSet_HTML = _oeiupac.OECharSet_HTML
OECharSet_UTF8 = _oeiupac.OECharSet_UTF8
OECharSet_SJIS = _oeiupac.OECharSet_SJIS
OECharSet_EUCJP = _oeiupac.OECharSet_EUCJP
OECharSet_Latin1 = _oeiupac.OECharSet_Latin1
OELanguage_ENGLISH = _oeiupac.OELanguage_ENGLISH
OELanguage_AMERICAN = _oeiupac.OELanguage_AMERICAN
OELanguage_BRITISH = _oeiupac.OELanguage_BRITISH
OELanguage_INTERNATIONAL = _oeiupac.OELanguage_INTERNATIONAL
OELanguage_CHINESE = _oeiupac.OELanguage_CHINESE
OELanguage_DANISH = _oeiupac.OELanguage_DANISH
OELanguage_DUTCH = _oeiupac.OELanguage_DUTCH
OELanguage_FRENCH = _oeiupac.OELanguage_FRENCH
OELanguage_GERMAN = _oeiupac.OELanguage_GERMAN
OELanguage_GREEK = _oeiupac.OELanguage_GREEK
OELanguage_HUNGARIAN = _oeiupac.OELanguage_HUNGARIAN
OELanguage_IRISH = _oeiupac.OELanguage_IRISH
OELanguage_ITALIAN = _oeiupac.OELanguage_ITALIAN
OELanguage_JAPANESE = _oeiupac.OELanguage_JAPANESE
OELanguage_POLISH = _oeiupac.OELanguage_POLISH
OELanguage_PORTUGUESE = _oeiupac.OELanguage_PORTUGUESE
OELanguage_ROMANIAN = _oeiupac.OELanguage_ROMANIAN
OELanguage_RUSSIAN = _oeiupac.OELanguage_RUSSIAN
OELanguage_SLOVAK = _oeiupac.OELanguage_SLOVAK
OELanguage_SPANISH = _oeiupac.OELanguage_SPANISH
OELanguage_SWEDISH = _oeiupac.OELanguage_SWEDISH
OELanguage_WELSH = _oeiupac.OELanguage_WELSH

def OENameLocant(loc: 'unsigned int', iupac: 'bool'=False) -> "std::string":
    """
    OENameLocant(unsigned int loc, bool iupac=False) -> std::string
    OENameLocant(unsigned int loc) -> std::string
    """
    return _oeiupac.OENameLocant(loc, iupac)

def OEParseIUPACName(mol: 'OEMolBase', name: 'char const *') -> "bool":
    """OEParseIUPACName(OEMolBase mol, char const * name) -> bool"""
    return _oeiupac.OEParseIUPACName(mol, name)

def OECreateIUPACName(*args) -> "std::string":
    """
    OECreateIUPACName(OEMolBase mol, unsigned char const * style) -> std::string
    OECreateIUPACName(OEMolBase mol) -> std::string
    """
    return _oeiupac.OECreateIUPACName(*args)

def OEGetIUPACNamStyle(style: 'std::string const &') -> "unsigned char const *":
    """OEGetIUPACNamStyle(std::string const & style) -> unsigned char const *"""
    return _oeiupac.OEGetIUPACNamStyle(style)

def OEGetCIPStereo(*args) -> "char":
    """
    OEGetCIPStereo(OEMolBase mol, OEAtomBase atm) -> char
    OEGetCIPStereo(OEMolBase mol, OEBondBase bnd) -> char
    """
    return _oeiupac.OEGetCIPStereo(*args)

def OESetCIPStereo(*args) -> "bool":
    """
    OESetCIPStereo(OEMolBase mol, OEAtomBase atm, char s) -> bool
    OESetCIPStereo(OEMolBase mol, OEBondBase bnd, char s) -> bool
    """
    return _oeiupac.OESetCIPStereo(*args)

def OECapitalizeName(ptr: 'char const *') -> "std::string":
    """OECapitalizeName(char const * ptr) -> std::string"""
    return _oeiupac.OECapitalizeName(ptr)

def OELowerCaseName(ptr: 'char const *') -> "std::string":
    """OELowerCaseName(char const * ptr) -> std::string"""
    return _oeiupac.OELowerCaseName(ptr)

def OEReorderIndexName(ptr: 'char const *') -> "std::string":
    """OEReorderIndexName(char const * ptr) -> std::string"""
    return _oeiupac.OEReorderIndexName(ptr)

def OEGetIUPACLanguage(langStr: 'std::string const &') -> "unsigned int":
    """OEGetIUPACLanguage(std::string const & langStr) -> unsigned int"""
    return _oeiupac.OEGetIUPACLanguage(langStr)

def OEFromLanguage(ptr: 'char const *', lang: 'unsigned int') -> "std::string":
    """OEFromLanguage(char const * ptr, unsigned int lang) -> std::string"""
    return _oeiupac.OEFromLanguage(ptr, lang)

def OEToLanguage(ptr: 'char const *', lang: 'unsigned int') -> "std::string":
    """OEToLanguage(char const * ptr, unsigned int lang) -> std::string"""
    return _oeiupac.OEToLanguage(ptr, lang)

def OEToBritish(ptr: 'char const *', sulph: 'bool') -> "std::string":
    """OEToBritish(char const * ptr, bool sulph) -> std::string"""
    return _oeiupac.OEToBritish(ptr, sulph)

def OEToChinese(ptr: 'char const *') -> "std::string":
    """OEToChinese(char const * ptr) -> std::string"""
    return _oeiupac.OEToChinese(ptr)

def OEToDanish(ptr: 'char const *') -> "std::string":
    """OEToDanish(char const * ptr) -> std::string"""
    return _oeiupac.OEToDanish(ptr)

def OEToDutch(ptr: 'char const *') -> "std::string":
    """OEToDutch(char const * ptr) -> std::string"""
    return _oeiupac.OEToDutch(ptr)

def OEToFrench(ptr: 'char const *') -> "std::string":
    """OEToFrench(char const * ptr) -> std::string"""
    return _oeiupac.OEToFrench(ptr)

def OEToGerman(ptr: 'char const *') -> "std::string":
    """OEToGerman(char const * ptr) -> std::string"""
    return _oeiupac.OEToGerman(ptr)

def OEToGreek(ptr: 'char const *') -> "std::string":
    """OEToGreek(char const * ptr) -> std::string"""
    return _oeiupac.OEToGreek(ptr)

def OEToHungarian(ptr: 'char const *') -> "std::string":
    """OEToHungarian(char const * ptr) -> std::string"""
    return _oeiupac.OEToHungarian(ptr)

def OEToIrish(ptr: 'char const *') -> "std::string":
    """OEToIrish(char const * ptr) -> std::string"""
    return _oeiupac.OEToIrish(ptr)

def OEToItalian(ptr: 'char const *') -> "std::string":
    """OEToItalian(char const * ptr) -> std::string"""
    return _oeiupac.OEToItalian(ptr)

def OEToJapanese(ptr: 'char const *') -> "std::string":
    """OEToJapanese(char const * ptr) -> std::string"""
    return _oeiupac.OEToJapanese(ptr)

def OEToPolish(ptr: 'char const *') -> "std::string":
    """OEToPolish(char const * ptr) -> std::string"""
    return _oeiupac.OEToPolish(ptr)

def OEToPortuguese(ptr: 'char const *') -> "std::string":
    """OEToPortuguese(char const * ptr) -> std::string"""
    return _oeiupac.OEToPortuguese(ptr)

def OEToRomanian(ptr: 'char const *') -> "std::string":
    """OEToRomanian(char const * ptr) -> std::string"""
    return _oeiupac.OEToRomanian(ptr)

def OEToRussian(ptr: 'char const *') -> "std::string":
    """OEToRussian(char const * ptr) -> std::string"""
    return _oeiupac.OEToRussian(ptr)

def OEToSlovak(ptr: 'char const *') -> "std::string":
    """OEToSlovak(char const * ptr) -> std::string"""
    return _oeiupac.OEToSlovak(ptr)

def OEToSpanish(ptr: 'char const *') -> "std::string":
    """OEToSpanish(char const * ptr) -> std::string"""
    return _oeiupac.OEToSpanish(ptr)

def OEToSwedish(ptr: 'char const *') -> "std::string":
    """OEToSwedish(char const * ptr) -> std::string"""
    return _oeiupac.OEToSwedish(ptr)

def OEToWelsh(ptr: 'char const *') -> "std::string":
    """OEToWelsh(char const * ptr) -> std::string"""
    return _oeiupac.OEToWelsh(ptr)

def OEFromBritish(ptr: 'char const *') -> "std::string":
    """OEFromBritish(char const * ptr) -> std::string"""
    return _oeiupac.OEFromBritish(ptr)

def OEFromChinese(ptr: 'char const *') -> "std::string":
    """OEFromChinese(char const * ptr) -> std::string"""
    return _oeiupac.OEFromChinese(ptr)

def OEFromDanish(ptr: 'char const *') -> "std::string":
    """OEFromDanish(char const * ptr) -> std::string"""
    return _oeiupac.OEFromDanish(ptr)

def OEFromDutch(ptr: 'char const *') -> "std::string":
    """OEFromDutch(char const * ptr) -> std::string"""
    return _oeiupac.OEFromDutch(ptr)

def OEFromFrench(ptr: 'char const *') -> "std::string":
    """OEFromFrench(char const * ptr) -> std::string"""
    return _oeiupac.OEFromFrench(ptr)

def OEFromGerman(ptr: 'char const *') -> "std::string":
    """OEFromGerman(char const * ptr) -> std::string"""
    return _oeiupac.OEFromGerman(ptr)

def OEFromGreek(ptr: 'char const *') -> "std::string":
    """OEFromGreek(char const * ptr) -> std::string"""
    return _oeiupac.OEFromGreek(ptr)

def OEFromHungarian(ptr: 'char const *') -> "std::string":
    """OEFromHungarian(char const * ptr) -> std::string"""
    return _oeiupac.OEFromHungarian(ptr)

def OEFromIrish(ptr: 'char const *') -> "std::string":
    """OEFromIrish(char const * ptr) -> std::string"""
    return _oeiupac.OEFromIrish(ptr)

def OEFromItalian(ptr: 'char const *') -> "std::string":
    """OEFromItalian(char const * ptr) -> std::string"""
    return _oeiupac.OEFromItalian(ptr)

def OEFromJapanese(ptr: 'char const *') -> "std::string":
    """OEFromJapanese(char const * ptr) -> std::string"""
    return _oeiupac.OEFromJapanese(ptr)

def OEFromPolish(ptr: 'char const *') -> "std::string":
    """OEFromPolish(char const * ptr) -> std::string"""
    return _oeiupac.OEFromPolish(ptr)

def OEFromPortuguese(ptr: 'char const *') -> "std::string":
    """OEFromPortuguese(char const * ptr) -> std::string"""
    return _oeiupac.OEFromPortuguese(ptr)

def OEFromRomanian(ptr: 'char const *') -> "std::string":
    """OEFromRomanian(char const * ptr) -> std::string"""
    return _oeiupac.OEFromRomanian(ptr)

def OEFromRussian(ptr: 'char const *') -> "std::string":
    """OEFromRussian(char const * ptr) -> std::string"""
    return _oeiupac.OEFromRussian(ptr)

def OEFromSlovak(ptr: 'char const *') -> "std::string":
    """OEFromSlovak(char const * ptr) -> std::string"""
    return _oeiupac.OEFromSlovak(ptr)

def OEFromSpanish(ptr: 'char const *') -> "std::string":
    """OEFromSpanish(char const * ptr) -> std::string"""
    return _oeiupac.OEFromSpanish(ptr)

def OEFromSwedish(ptr: 'char const *') -> "std::string":
    """OEFromSwedish(char const * ptr) -> std::string"""
    return _oeiupac.OEFromSwedish(ptr)

def OEFromWelsh(ptr: 'char const *') -> "std::string":
    """OEFromWelsh(char const * ptr) -> std::string"""
    return _oeiupac.OEFromWelsh(ptr)

def OEGetIUPACCharSet(charset: 'std::string const &') -> "unsigned int":
    """OEGetIUPACCharSet(std::string const & charset) -> unsigned int"""
    return _oeiupac.OEGetIUPACCharSet(charset)

def OEToASCII(ptr: 'char const *', remove_markup: 'bool const'=True) -> "std::string":
    """
    OEToASCII(char const * ptr, bool const remove_markup=True) -> std::string
    OEToASCII(char const * ptr) -> std::string
    """
    return _oeiupac.OEToASCII(ptr, remove_markup)

def OEToUTF8(ptr: 'char const *', remove_markup: 'bool const'=True) -> "std::string":
    """
    OEToUTF8(char const * ptr, bool const remove_markup=True) -> std::string
    OEToUTF8(char const * ptr) -> std::string
    """
    return _oeiupac.OEToUTF8(ptr, remove_markup)

def OEFromUTF8(ptr: 'char const *') -> "std::string":
    """OEFromUTF8(char const * ptr) -> std::string"""
    return _oeiupac.OEFromUTF8(ptr)

def OEToHTML(ptr: 'char const *') -> "std::string":
    """OEToHTML(char const * ptr) -> std::string"""
    return _oeiupac.OEToHTML(ptr)

def OEFromHTML(ptr: 'char const *') -> "std::string":
    """OEFromHTML(char const * ptr) -> std::string"""
    return _oeiupac.OEFromHTML(ptr)

def OEToSJIS(ptr: 'char const *') -> "std::string":
    """OEToSJIS(char const * ptr) -> std::string"""
    return _oeiupac.OEToSJIS(ptr)

def OEToEUCJP(ptr: 'char const *') -> "std::string":
    """OEToEUCJP(char const * ptr) -> std::string"""
    return _oeiupac.OEToEUCJP(ptr)

def OEFromKOI8R(ptr: 'char const *') -> "std::string":
    """OEFromKOI8R(char const * ptr) -> std::string"""
    return _oeiupac.OEFromKOI8R(ptr)
OE_OEIUPAC_VERSION = _oeiupac.OE_OEIUPAC_VERSION

def OEIUPACGetRelease() -> "char const *":
    """OEIUPACGetRelease() -> char const *"""
    return _oeiupac.OEIUPACGetRelease()

def OEIUPACGetVersion() -> "unsigned int":
    """OEIUPACGetVersion() -> unsigned int"""
    return _oeiupac.OEIUPACGetVersion()

def OEIUPACGetArch() -> "char const *":
    """OEIUPACGetArch() -> char const *"""
    return _oeiupac.OEIUPACGetArch()

def OEIUPACGetPlatform() -> "char const *":
    """OEIUPACGetPlatform() -> char const *"""
    return _oeiupac.OEIUPACGetPlatform()

def OEIUPACIsLicensed(feature: 'char const *'=None, expdate: 'unsigned int *'=None) -> "bool":
    """
    OEIUPACIsLicensed(char const * feature=None, unsigned int * expdate=None) -> bool
    OEIUPACIsLicensed(char const * feature=None) -> bool
    OEIUPACIsLicensed() -> bool
    """
    return _oeiupac.OEIUPACIsLicensed(feature, expdate)

def OEIUPACGetLicensee(*args) -> "std::string":
    """
    OEIUPACGetLicensee(std::string & licensee) -> bool
    OEIUPACGetLicensee() -> std::string
    """
    return _oeiupac.OEIUPACGetLicensee(*args)

def OEIUPACGetSite(*args) -> "std::string":
    """
    OEIUPACGetSite(std::string & site) -> bool
    OEIUPACGetSite() -> std::string
    """
    return _oeiupac.OEIUPACGetSite(*args)

cvar = _oeiupac.cvar
OENamStyleOpenEye = cvar.OENamStyleOpenEye
OENamStyleTraditional = cvar.OENamStyleTraditional
OENamStyleSystematic = cvar.OENamStyleSystematic
OENamStyleIUPAC = cvar.OENamStyleIUPAC
OENamStyleCAS = cvar.OENamStyleCAS
OENamStyleCASIndex = cvar.OENamStyleCASIndex
OENamStyleAutoNom = cvar.OENamStyleAutoNom
OENamStyleIUPAC79 = cvar.OENamStyleIUPAC79
OENamStyleIUPAC93 = cvar.OENamStyleIUPAC93
OENamStyleACDName = cvar.OENamStyleACDName

